@@ -156,6 +156,7 @@ class MainWindow(object):
         self.menu_help.add_command(label='Open Documentation', command=self.cmd_cricket_docs)
         self.menu_help.add_command(label='Open Cricket project page', command=self.cmd_cricket_page)
         self.menu_help.add_command(label='Open Cricket on GitHub', command=self.cmd_cricket_github)
+        self.menu_help.add_command(label='Open BeeWare project page', command=self.cmd_beeware_page)
 
         # last step - configure the menubar
         self.root['menu'] = self.menubar
@@ -391,7 +392,7 @@ class MainWindow(object):
         self.run_summary = StringVar()
         self.run_summary_label = Label(self.statusbar, textvariable=self.run_summary)
         self.run_summary_label.grid(column=1, row=0, sticky=(W, E))
-        self.run_summary.set('P:0 F:0 E:0 X:0 U:0 S:0')
+        self.run_summary.set('T:0 P:0 F:0 E:0 X:0 U:0 S:0')
 
         # Test progress
         self.progress_value = IntVar()
@@ -461,6 +462,10 @@ class MainWindow(object):
     def project(self, project):
         self._project = project
 
+        # Get a count of active tests to display in the status bar.
+        count, labels = self.project.find_tests(True)
+        self.run_summary.set('T:%s P:0 F:0 E:0 X:0 U:0 S:0' % count)
+
         # Populate the initial tree nodes. This is recursive, because
         # the tree could be of arbitrary depth.
         for testModule_name, testModule in sorted(project.items()):
@@ -541,6 +546,10 @@ class MainWindow(object):
         "Show the Cricket project page"
         webbrowser.open_new('http://pybee.org/cricket/')
 
+    def cmd_beeware_page(self):
+        "Show the Beeware project page"
+        webbrowser.open_new('http://pybee.org/')
+
     def cmd_cricket_github(self):
         "Show the Cricket GitHub repo"
         webbrowser.open_new('http://github.com/pybee/cricket')
@@ -749,7 +758,8 @@ class MainWindow(object):
         self.progress_value.set(self.progress_value.get() + 1)
 
         # Update the run summary
-        self.run_summary.set('P:%(pass)s F:%(fail)s E:%(error)s X:%(expected)s U:%(unexpected)s S:%(skip)s, ~%(remaining)s remaining' % {
+        self.run_summary.set('T:%(total)s P:%(pass)s F:%(fail)s E:%(error)s X:%(expected)s U:%(unexpected)s S:%(skip)s, ~%(remaining)s remaining' % {
+                'total': self.executor.total_count,
                 'pass': self.executor.result_count.get(TestMethod.STATUS_PASS, 0),
                 'fail': self.executor.result_count.get(TestMethod.STATUS_FAIL, 0),
                 'error': self.executor.result_count.get(TestMethod.STATUS_ERROR, 0),
@@ -799,7 +809,8 @@ class MainWindow(object):
         )
 
         # Reset the running summary.
-        self.run_summary.set('P:%(pass)s F:%(fail)s E:%(error)s X:%(expected)s U:%(unexpected)s S:%(skip)s' % {
+        self.run_summary.set('T:%(total)s P:%(pass)s F:%(fail)s E:%(error)s X:%(expected)s U:%(unexpected)s S:%(skip)s' % {
+                'total': self.executor.total_count,
                 'pass': self.executor.result_count.get(TestMethod.STATUS_PASS, 0),
                 'fail': self.executor.result_count.get(TestMethod.STATUS_FAIL, 0),
                 'error': self.executor.result_count.get(TestMethod.STATUS_ERROR, 0),
@@ -831,7 +842,7 @@ class MainWindow(object):
         self.stop_button.configure(state=DISABLED)
         self.run_all_button.configure(state=NORMAL)
         self.set_selected_button_state()
-        if self.executor.any_failed:
+        if self.executor and self.executor.any_failed:
             self.rerun_button.configure(state=NORMAL)
         else:
             self.rerun_button.configure(state=DISABLED)
@@ -858,9 +869,8 @@ class MainWindow(object):
             be executed
         """
         count, labels = self.project.find_tests(active, status, labels)
-
         self.run_status.set('Running...')
-        self.run_summary.set('P:0 F:0 E:0 X:0 U:0 S:0')
+        self.run_summary.set('T:%s P:0 F:0 E:0 X:0 U:0 S:0' % count)
 
         self.stop_button.configure(state=NORMAL)
         self.run_all_button.configure(state=DISABLED)
